@@ -130,11 +130,14 @@ define('custom:views/campaign/record/detail',
 
                 Administrativo: {
                     edit: ['*']
-                }
-                ,
+                },
 
                 'Gerente de Marketing': {
                     edit: ['*']
+                },
+
+                'Gerente Comercial': {
+                    edit: ['*']
                 }
             };
 
@@ -1167,8 +1170,9 @@ define('custom:views/campaign/record/detail',
             
             const entidadeContaCorrente = 'CCSoftContaCorrente'; 
             const nomeDoCampoLinkNaCC = 'account1Id';
-            const gerenteMarketingId = '6972b01c5a8cfa7ea'; //696f93ba2e446fca2
-            const gerenteMarketingName = 'Gerente de Marketing'; //696f93ba2e446fca2
+            const gerenteMarketingId = '6972b01c5a8cfa7ea';
+            const gerenteMarketingName = 'Gerente de Marketing';
+            const gerenteComercialName = 'Gerente Comercial';
             
             if (!this.contasCorrentesCollection) {
                 //this.contasCorrentesCollection = this.getCollectionFactory().create(entidadeContaCorrente);
@@ -1193,6 +1197,11 @@ define('custom:views/campaign/record/detail',
                                 type: 'equals',
                                 field: 'account1Name',
                                 value: gerenteMarketingName
+                            },
+                            {
+                                type: 'equals',
+                                field: 'account1Name',
+                                value: gerenteComercialName
                             }
                         ]
                     }
@@ -1347,12 +1356,7 @@ define('custom:views/campaign/record/detail',
                     tipoConta: m.get('cSoftTipoCC')
                 }));
 
-                // Validação mínima
-                if (contasCorrentesData.length === 0) {
-                    Espo.Ui.error('Nenhuma Conta Corrente foi encontrada para a Rede vinculada.');
-                }
-
-                if (contasCorrentesData.length < 3) {
+                if (contasCorrentesData.length < 1) {
                     throw new Error('Rede sem contas correntes suficientes vinculadas.');
                 }
 
